<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'SPIP forum (prevez ha publik)',
	'forum_slogan' => 'Merañ ar foromoù preves ha foran e-barzh SPIP',
];
